public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
* [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests
@ 2022-12-19 19:21 Alex Hung
  2022-12-20 11:55 ` Melissa Wen
                   ` (3 more replies)
  0 siblings, 4 replies; 8+ messages in thread
From: Alex Hung @ 2022-12-19 19:21 UTC (permalink / raw)
  To: igt-dev; +Cc: markyacoub

64d0ff72 introduced a workaround for ctm-max but the condition caused
other ctm tests to skip unintentionally on some platforms.

The patch improves the condition by keeping the original condition
for i915 and checking degamma and gamma props for others. The
following subtests will be executed instead of skipped.

  kms_color@ctm-0-25@*
  kms_color@ctm-0-50@*
  kms_color@ctm-0-75@*
  kms_color@ctm-red-to-blue@*
  kms_color@ctm-negative@*

Signed-off-by: Alex Hung <alex.hung@amd.com>
---
 tests/kms_color.c | 30 +++++++++++++++++++++---------
 1 file changed, 21 insertions(+), 9 deletions(-)

diff --git a/tests/kms_color.c b/tests/kms_color.c
index d016cefb..450bf7ca 100644
--- a/tests/kms_color.c
+++ b/tests/kms_color.c
@@ -446,6 +446,26 @@ end:
 	return ret;
 }
 
+static bool is_gamma_degamma_supported(data_t *data,
+				       igt_plane_t *primary,
+				       color_t *before,
+				       color_t *after)
+{
+	/*
+	 * Don't program LUT's for max CTM cases, as limitation of
+	 * representing intermediate values between 0 and 1.0 causes
+	 * rounding issues and inaccuracies leading to crc mismatch.
+	 */
+	if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t)))
+		return true;
+
+	if (igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT) &&
+	    igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT))
+		return true;
+
+	return false;
+}
+
 /*
  * Draw 3 rectangles using before colors with the ctm matrix apply and verify
  * the CRC is equal to using after colors with an identify ctm matrix.
@@ -493,14 +513,7 @@ static bool test_pipe_ctm(data_t *data,
 	igt_assert(fb_modeset_id);
 	igt_plane_set_fb(primary, &fb_modeset);
 
-	/*
-	 * Don't program LUT's for max CTM cases, as limitation of
-	 * representing intermediate values between 0 and 1.0 causes
-	 * rounding issues and inaccuracies leading to crc mismatch.
-	 */
-	if (memcmp(before, after, sizeof(color_t))) {
-		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
-		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
+	if (is_gamma_degamma_supported(data, primary, before, after)) {
 
 		degamma_linear = generate_table(data->degamma_lut_size, 1.0);
 		gamma_linear = generate_table(data->gamma_lut_size, 1.0);
@@ -508,7 +521,6 @@ static bool test_pipe_ctm(data_t *data,
 		set_degamma(data, primary->pipe, degamma_linear);
 		set_gamma(data, primary->pipe, gamma_linear);
 	} else {
-		/* Disable Degamma and Gamma for ctm max test */
 		disable_degamma(primary->pipe);
 		disable_gamma(primary->pipe);
 	}
-- 
2.25.1

^ permalink raw reply related	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-19 19:21 [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests Alex Hung
@ 2022-12-20 11:55 ` Melissa Wen
  2022-12-20 18:20   ` Alex Hung
  2022-12-20 15:22 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
                   ` (2 subsequent siblings)
  3 siblings, 1 reply; 8+ messages in thread
From: Melissa Wen @ 2022-12-20 11:55 UTC (permalink / raw)
  To: Alex Hung; +Cc: igt-dev, markyacoub

[-- Attachment #1: Type: text/plain, Size: 3427 bytes --]

On 12/19, Alex Hung wrote:
> 64d0ff72 introduced a workaround for ctm-max but the condition caused
> other ctm tests to skip unintentionally on some platforms.

Hi Alex,

Can't we just drop this gamma/degamma setup for CTM tests?

I remember thinking about removing this setup before... From DRM docs,
"Each of the properties are optional." so I don't see an explicity
reason for degamma/gamma dependencies. I think we should only test the
CTM property here, or change the name of the subtest to describe a full
color mgmt testing.

I took a look at previous discussions on having or not degamma/gamma
here and if it's an intel limitation, than I prefer to explicitly
restrict it for i915 HW. What do you think?

Best regards,

Melissa

> 
> The patch improves the condition by keeping the original condition
> for i915 and checking degamma and gamma props for others. The
> following subtests will be executed instead of skipped.
> 
>   kms_color@ctm-0-25@*
>   kms_color@ctm-0-50@*
>   kms_color@ctm-0-75@*
>   kms_color@ctm-red-to-blue@*
>   kms_color@ctm-negative@*
> 
> Signed-off-by: Alex Hung <alex.hung@amd.com>
> ---
>  tests/kms_color.c | 30 +++++++++++++++++++++---------
>  1 file changed, 21 insertions(+), 9 deletions(-)
> 
> diff --git a/tests/kms_color.c b/tests/kms_color.c
> index d016cefb..450bf7ca 100644
> --- a/tests/kms_color.c
> +++ b/tests/kms_color.c
> @@ -446,6 +446,26 @@ end:
>  	return ret;
>  }
>  
> +static bool is_gamma_degamma_supported(data_t *data,
> +				       igt_plane_t *primary,
> +				       color_t *before,
> +				       color_t *after)
> +{
> +	/*
> +	 * Don't program LUT's for max CTM cases, as limitation of
> +	 * representing intermediate values between 0 and 1.0 causes
> +	 * rounding issues and inaccuracies leading to crc mismatch.
> +	 */
> +	if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t)))
> +		return true;
> +
> +	if (igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT) &&
> +	    igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT))
> +		return true;
> +
> +	return false;
> +}
> +
>  /*
>   * Draw 3 rectangles using before colors with the ctm matrix apply and verify
>   * the CRC is equal to using after colors with an identify ctm matrix.
> @@ -493,14 +513,7 @@ static bool test_pipe_ctm(data_t *data,
>  	igt_assert(fb_modeset_id);
>  	igt_plane_set_fb(primary, &fb_modeset);
>  
> -	/*
> -	 * Don't program LUT's for max CTM cases, as limitation of
> -	 * representing intermediate values between 0 and 1.0 causes
> -	 * rounding issues and inaccuracies leading to crc mismatch.
> -	 */
> -	if (memcmp(before, after, sizeof(color_t))) {
> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
> +	if (is_gamma_degamma_supported(data, primary, before, after)) {
>  
>  		degamma_linear = generate_table(data->degamma_lut_size, 1.0);
>  		gamma_linear = generate_table(data->gamma_lut_size, 1.0);
> @@ -508,7 +521,6 @@ static bool test_pipe_ctm(data_t *data,
>  		set_degamma(data, primary->pipe, degamma_linear);
>  		set_gamma(data, primary->pipe, gamma_linear);
>  	} else {
> -		/* Disable Degamma and Gamma for ctm max test */
>  		disable_degamma(primary->pipe);
>  		disable_gamma(primary->pipe);
>  	}
> -- 
> 2.25.1
> 

[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 833 bytes --]

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] ✓ Fi.CI.BAT: success for tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-19 19:21 [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests Alex Hung
  2022-12-20 11:55 ` Melissa Wen
@ 2022-12-20 15:22 ` Patchwork
  2022-12-20 18:14 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
  2022-12-21 11:08 ` [igt-dev] ✗ Fi.CI.BUILD: failure for tests/kms_color: Reduce skips on some ctm-* tests (rev2) Patchwork
  3 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2022-12-20 15:22 UTC (permalink / raw)
  To: Alex Hung; +Cc: igt-dev

[-- Attachment #1: Type: text/plain, Size: 5143 bytes --]

== Series Details ==

Series: tests/kms_color: Reduce skips on some ctm-* tests
URL   : https://patchwork.freedesktop.org/series/112075/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_12516 -> IGTPW_8248
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html

Participating hosts (41 -> 43)
------------------------------

  Additional (2): bat-rpls-1 bat-rpls-2 

Known issues
------------

  Here are the changes found in IGTPW_8248 that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@i915_selftest@live@guc_hang:
    - fi-kbl-soraka:      [PASS][1] -> [INCOMPLETE][2] ([i915#7640])
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/fi-kbl-soraka/igt@i915_selftest@live@guc_hang.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/fi-kbl-soraka/igt@i915_selftest@live@guc_hang.html

  * igt@i915_selftest@live@hangcheck:
    - fi-hsw-4770:        [PASS][3] -> [INCOMPLETE][4] ([i915#4785])
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/fi-hsw-4770/igt@i915_selftest@live@hangcheck.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/fi-hsw-4770/igt@i915_selftest@live@hangcheck.html

  * igt@kms_chamelium@common-hpd-after-suspend:
    - bat-adlp-4:         NOTRUN -> [SKIP][5] ([fdo#111827])
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/bat-adlp-4/igt@kms_chamelium@common-hpd-after-suspend.html

  * igt@runner@aborted:
    - fi-hsw-4770:        NOTRUN -> [FAIL][6] ([fdo#109271] / [i915#4312] / [i915#5594])
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/fi-hsw-4770/igt@runner@aborted.html

  
#### Possible fixes ####

  * igt@gem_exec_suspend@basic-s0@smem:
    - {bat-adlp-6}:       [DMESG-WARN][7] ([i915#2867]) -> [PASS][8] +1 similar issue
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/bat-adlp-6/igt@gem_exec_suspend@basic-s0@smem.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/bat-adlp-6/igt@gem_exec_suspend@basic-s0@smem.html

  * igt@i915_pm_rpm@module-reload:
    - bat-adlp-4:         [INCOMPLETE][9] -> [PASS][10]
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/bat-adlp-4/igt@i915_pm_rpm@module-reload.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/bat-adlp-4/igt@i915_pm_rpm@module-reload.html

  * igt@i915_selftest@live@gt_heartbeat:
    - fi-apl-guc:         [DMESG-FAIL][11] ([i915#5334]) -> [PASS][12]
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/fi-apl-guc/igt@i915_selftest@live@gt_heartbeat.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/fi-apl-guc/igt@i915_selftest@live@gt_heartbeat.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [fdo#109271]: https://bugs.freedesktop.org/show_bug.cgi?id=109271
  [fdo#109285]: https://bugs.freedesktop.org/show_bug.cgi?id=109285
  [fdo#109295]: https://bugs.freedesktop.org/show_bug.cgi?id=109295
  [fdo#111827]: https://bugs.freedesktop.org/show_bug.cgi?id=111827
  [i915#1072]: https://gitlab.freedesktop.org/drm/intel/issues/1072
  [i915#1845]: https://gitlab.freedesktop.org/drm/intel/issues/1845
  [i915#1849]: https://gitlab.freedesktop.org/drm/intel/issues/1849
  [i915#2582]: https://gitlab.freedesktop.org/drm/intel/issues/2582
  [i915#2867]: https://gitlab.freedesktop.org/drm/intel/issues/2867
  [i915#3282]: https://gitlab.freedesktop.org/drm/intel/issues/3282
  [i915#3546]: https://gitlab.freedesktop.org/drm/intel/issues/3546
  [i915#3555]: https://gitlab.freedesktop.org/drm/intel/issues/3555
  [i915#3637]: https://gitlab.freedesktop.org/drm/intel/issues/3637
  [i915#3708]: https://gitlab.freedesktop.org/drm/intel/issues/3708
  [i915#4258]: https://gitlab.freedesktop.org/drm/intel/issues/4258
  [i915#4312]: https://gitlab.freedesktop.org/drm/intel/issues/4312
  [i915#4613]: https://gitlab.freedesktop.org/drm/intel/issues/4613
  [i915#4785]: https://gitlab.freedesktop.org/drm/intel/issues/4785
  [i915#5334]: https://gitlab.freedesktop.org/drm/intel/issues/5334
  [i915#5594]: https://gitlab.freedesktop.org/drm/intel/issues/5594
  [i915#6367]: https://gitlab.freedesktop.org/drm/intel/issues/6367
  [i915#6621]: https://gitlab.freedesktop.org/drm/intel/issues/6621
  [i915#7456]: https://gitlab.freedesktop.org/drm/intel/issues/7456
  [i915#7561]: https://gitlab.freedesktop.org/drm/intel/issues/7561
  [i915#7640]: https://gitlab.freedesktop.org/drm/intel/issues/7640


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_7100 -> IGTPW_8248

  CI-20190529: 20190529
  CI_DRM_12516: fc2ae74d6521d5237f8ad1ae6bf985a6eb3f1ea2 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_8248: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html
  IGT_7100: 04466b02a9b5356d266a899daa5183c1f6b0e20f @ https://gitlab.freedesktop.org/drm/igt-gpu-tools.git

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html

[-- Attachment #2: Type: text/html, Size: 4759 bytes --]

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] ✗ Fi.CI.IGT: failure for tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-19 19:21 [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests Alex Hung
  2022-12-20 11:55 ` Melissa Wen
  2022-12-20 15:22 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
@ 2022-12-20 18:14 ` Patchwork
  2022-12-21 11:08 ` [igt-dev] ✗ Fi.CI.BUILD: failure for tests/kms_color: Reduce skips on some ctm-* tests (rev2) Patchwork
  3 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2022-12-20 18:14 UTC (permalink / raw)
  To: Alex Hung; +Cc: igt-dev

[-- Attachment #1: Type: text/plain, Size: 30482 bytes --]

== Series Details ==

Series: tests/kms_color: Reduce skips on some ctm-* tests
URL   : https://patchwork.freedesktop.org/series/112075/
State : failure

== Summary ==

CI Bug Log - changes from CI_DRM_12516_full -> IGTPW_8248_full
====================================================

Summary
-------

  **FAILURE**

  Serious unknown changes coming with IGTPW_8248_full absolutely need to be
  verified manually.
  
  If you think the reported changes have nothing to do with the changes
  introduced in IGTPW_8248_full, please notify your bug team to allow them
  to document this new failure mode, which will reduce false positives in CI.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html

Participating hosts (13 -> 10)
------------------------------

  Missing    (3): pig-skl-6260u pig-kbl-iris pig-glk-j5005 

Possible new issues
-------------------

  Here are the unknown changes that may have been introduced in IGTPW_8248_full:

### IGT changes ###

#### Possible regressions ####

  * igt@gem_partial_pwrite_pread@writes-after-reads:
    - shard-apl:          NOTRUN -> [INCOMPLETE][1]
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@gem_partial_pwrite_pread@writes-after-reads.html

  * igt@kms_color@ctm-max@pipe-a-hdmi-a-1:
    - shard-glk:          [PASS][2] -> [FAIL][3] +2 similar issues
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk5/igt@kms_color@ctm-max@pipe-a-hdmi-a-1.html
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk3/igt@kms_color@ctm-max@pipe-a-hdmi-a-1.html

  
#### Suppressed ####

  The following results come from untrusted machines, tests, or statuses.
  They do not affect the overall result.

  * {igt@gem_ccs@block-multicopy-compressed}:
    - {shard-tglu}:       NOTRUN -> [SKIP][4] +1 similar issue
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-8/igt@gem_ccs@block-multicopy-compressed.html

  * igt@kms_color@ctm-max@pipe-c-hdmi-a-4:
    - {shard-dg1}:        NOTRUN -> [FAIL][5] +3 similar issues
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-dg1-15/igt@kms_color@ctm-max@pipe-c-hdmi-a-4.html

  * igt@vc4/vc4_tiling@get-bad-modifier:
    - {shard-rkl}:        NOTRUN -> [SKIP][6]
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-4/igt@vc4/vc4_tiling@get-bad-modifier.html
    - {shard-dg1}:        NOTRUN -> [SKIP][7]
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-dg1-14/igt@vc4/vc4_tiling@get-bad-modifier.html

  
Known issues
------------

  Here are the changes found in IGTPW_8248_full that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@gem_caching@read-writes:
    - shard-apl:          [PASS][8] -> [INCOMPLETE][9] ([i915#7708])
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl7/igt@gem_caching@read-writes.html
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl2/igt@gem_caching@read-writes.html

  * igt@gem_exec_fair@basic-pace@rcs0:
    - shard-glk:          [PASS][10] -> [FAIL][11] ([i915#2842])
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk7/igt@gem_exec_fair@basic-pace@rcs0.html
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk1/igt@gem_exec_fair@basic-pace@rcs0.html

  * igt@gem_exec_schedule@thriceslice:
    - shard-snb:          NOTRUN -> [SKIP][12] ([fdo#109271]) +87 similar issues
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-snb5/igt@gem_exec_schedule@thriceslice.html

  * igt@gem_lmem_swapping@massive:
    - shard-apl:          NOTRUN -> [SKIP][13] ([fdo#109271] / [i915#4613])
   [13]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl2/igt@gem_lmem_swapping@massive.html

  * igt@gem_lmem_swapping@random:
    - shard-glk:          NOTRUN -> [SKIP][14] ([fdo#109271] / [i915#4613]) +1 similar issue
   [14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk3/igt@gem_lmem_swapping@random.html

  * igt@gem_pread@exhaustion:
    - shard-apl:          NOTRUN -> [WARN][15] ([i915#2658])
   [15]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl2/igt@gem_pread@exhaustion.html

  * igt@gem_spin_batch@legacy@bsd:
    - shard-apl:          [PASS][16] -> [FAIL][17] ([i915#2898])
   [16]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl6/igt@gem_spin_batch@legacy@bsd.html
   [17]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@gem_spin_batch@legacy@bsd.html

  * igt@gem_userptr_blits@input-checking:
    - shard-apl:          NOTRUN -> [DMESG-WARN][18] ([i915#4991])
   [18]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@gem_userptr_blits@input-checking.html
    - shard-glk:          NOTRUN -> [DMESG-WARN][19] ([i915#4991])
   [19]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk5/igt@gem_userptr_blits@input-checking.html

  * igt@i915_selftest@live@gt_heartbeat:
    - shard-glk:          [PASS][20] -> [DMESG-FAIL][21] ([i915#5334])
   [20]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk9/igt@i915_selftest@live@gt_heartbeat.html
   [21]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk3/igt@i915_selftest@live@gt_heartbeat.html

  * igt@kms_ccs@pipe-b-crc-primary-rotation-180-y_tiled_gen12_mc_ccs:
    - shard-apl:          NOTRUN -> [SKIP][22] ([fdo#109271] / [i915#3886]) +3 similar issues
   [22]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl2/igt@kms_ccs@pipe-b-crc-primary-rotation-180-y_tiled_gen12_mc_ccs.html

  * igt@kms_ccs@pipe-c-missing-ccs-buffer-y_tiled_gen12_mc_ccs:
    - shard-glk:          NOTRUN -> [SKIP][23] ([fdo#109271] / [i915#3886])
   [23]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk1/igt@kms_ccs@pipe-c-missing-ccs-buffer-y_tiled_gen12_mc_ccs.html

  * igt@kms_cdclk@mode-transition:
    - shard-glk:          NOTRUN -> [SKIP][24] ([fdo#109271]) +72 similar issues
   [24]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk8/igt@kms_cdclk@mode-transition.html

  * igt@kms_chamelium@dp-hpd-fast:
    - shard-glk:          NOTRUN -> [SKIP][25] ([fdo#109271] / [fdo#111827]) +3 similar issues
   [25]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk4/igt@kms_chamelium@dp-hpd-fast.html

  * igt@kms_chamelium@vga-hpd-without-ddc:
    - shard-snb:          NOTRUN -> [SKIP][26] ([fdo#109271] / [fdo#111827]) +3 similar issues
   [26]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-snb4/igt@kms_chamelium@vga-hpd-without-ddc.html
    - shard-apl:          NOTRUN -> [SKIP][27] ([fdo#109271] / [fdo#111827]) +7 similar issues
   [27]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl3/igt@kms_chamelium@vga-hpd-without-ddc.html

  * igt@kms_dsc@dsc-with-bpc-formats:
    - shard-glk:          NOTRUN -> [SKIP][28] ([fdo#109271] / [i915#7205])
   [28]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk6/igt@kms_dsc@dsc-with-bpc-formats.html
    - shard-apl:          NOTRUN -> [SKIP][29] ([fdo#109271] / [i915#7205])
   [29]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl1/igt@kms_dsc@dsc-with-bpc-formats.html

  * igt@kms_flip@2x-flip-vs-expired-vblank@bc-hdmi-a1-hdmi-a2:
    - shard-glk:          [PASS][30] -> [FAIL][31] ([i915#79])
   [30]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk8/igt@kms_flip@2x-flip-vs-expired-vblank@bc-hdmi-a1-hdmi-a2.html
   [31]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk8/igt@kms_flip@2x-flip-vs-expired-vblank@bc-hdmi-a1-hdmi-a2.html

  * igt@kms_frontbuffer_tracking@psr-1p-primscrn-pri-shrfb-draw-mmap-cpu:
    - shard-apl:          NOTRUN -> [SKIP][32] ([fdo#109271]) +124 similar issues
   [32]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl6/igt@kms_frontbuffer_tracking@psr-1p-primscrn-pri-shrfb-draw-mmap-cpu.html

  * igt@kms_psr2_su@page_flip-nv12:
    - shard-glk:          NOTRUN -> [SKIP][33] ([fdo#109271] / [i915#658])
   [33]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk6/igt@kms_psr2_su@page_flip-nv12.html

  * igt@kms_psr2_su@page_flip-xrgb8888:
    - shard-apl:          NOTRUN -> [SKIP][34] ([fdo#109271] / [i915#658]) +1 similar issue
   [34]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl7/igt@kms_psr2_su@page_flip-xrgb8888.html

  * igt@kms_vblank@pipe-d-wait-idle:
    - shard-glk:          NOTRUN -> [SKIP][35] ([fdo#109271] / [i915#533])
   [35]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk9/igt@kms_vblank@pipe-d-wait-idle.html

  * igt@kms_writeback@writeback-pixel-formats:
    - shard-apl:          NOTRUN -> [SKIP][36] ([fdo#109271] / [i915#2437]) +1 similar issue
   [36]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@kms_writeback@writeback-pixel-formats.html
    - shard-glk:          NOTRUN -> [SKIP][37] ([fdo#109271] / [i915#2437]) +1 similar issue
   [37]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk9/igt@kms_writeback@writeback-pixel-formats.html

  * igt@sysfs_clients@recycle:
    - shard-apl:          NOTRUN -> [SKIP][38] ([fdo#109271] / [i915#2994])
   [38]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@sysfs_clients@recycle.html

  
#### Possible fixes ####

  * igt@drm_read@empty-block:
    - {shard-tglu}:       [SKIP][39] ([i915#7651]) -> [PASS][40] +1 similar issue
   [39]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-6/igt@drm_read@empty-block.html
   [40]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-8/igt@drm_read@empty-block.html

  * igt@fbdev@nullptr:
    - {shard-rkl}:        [SKIP][41] ([i915#2582]) -> [PASS][42]
   [41]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-4/igt@fbdev@nullptr.html
   [42]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@fbdev@nullptr.html

  * igt@gem_busy@close-race:
    - {shard-rkl}:        [TIMEOUT][43] -> [PASS][44]
   [43]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-5/igt@gem_busy@close-race.html
   [44]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-4/igt@gem_busy@close-race.html

  * igt@gem_eio@kms:
    - {shard-dg1}:        [FAIL][45] ([i915#5784]) -> [PASS][46]
   [45]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-dg1-19/igt@gem_eio@kms.html
   [46]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-dg1-19/igt@gem_eio@kms.html

  * igt@gem_exec_fair@basic-none@vecs0:
    - shard-glk:          [FAIL][47] ([i915#2842]) -> [PASS][48] +1 similar issue
   [47]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk4/igt@gem_exec_fair@basic-none@vecs0.html
   [48]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk3/igt@gem_exec_fair@basic-none@vecs0.html

  * igt@gem_exec_fair@basic-pace-solo@rcs0:
    - shard-apl:          [FAIL][49] ([i915#2842]) -> [PASS][50]
   [49]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl7/igt@gem_exec_fair@basic-pace-solo@rcs0.html
   [50]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl1/igt@gem_exec_fair@basic-pace-solo@rcs0.html

  * igt@gem_exec_reloc@basic-write-gtt-noreloc:
    - {shard-rkl}:        [SKIP][51] ([i915#3281]) -> [PASS][52]
   [51]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-2/igt@gem_exec_reloc@basic-write-gtt-noreloc.html
   [52]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-5/igt@gem_exec_reloc@basic-write-gtt-noreloc.html

  * igt@gem_madvise@dontneed-before-pwrite:
    - {shard-rkl}:        [SKIP][53] ([i915#3282]) -> [PASS][54]
   [53]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-3/igt@gem_madvise@dontneed-before-pwrite.html
   [54]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-5/igt@gem_madvise@dontneed-before-pwrite.html

  * igt@gem_partial_pwrite_pread@writes-after-reads-uncached:
    - shard-apl:          [INCOMPLETE][55] -> [PASS][56]
   [55]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl3/igt@gem_partial_pwrite_pread@writes-after-reads-uncached.html
   [56]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl6/igt@gem_partial_pwrite_pread@writes-after-reads-uncached.html

  * igt@gem_workarounds@suspend-resume-fd:
    - {shard-rkl}:        [DMESG-WARN][57] ([i915#5122]) -> [PASS][58]
   [57]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-3/igt@gem_workarounds@suspend-resume-fd.html
   [58]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-1/igt@gem_workarounds@suspend-resume-fd.html
    - {shard-tglu}:       [DMESG-WARN][59] ([i915#5122]) -> [PASS][60]
   [59]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-1/igt@gem_workarounds@suspend-resume-fd.html
   [60]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-7/igt@gem_workarounds@suspend-resume-fd.html

  * igt@gen9_exec_parse@allowed-single:
    - shard-apl:          [DMESG-WARN][61] ([i915#5566] / [i915#716]) -> [PASS][62]
   [61]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl8/igt@gen9_exec_parse@allowed-single.html
   [62]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl3/igt@gen9_exec_parse@allowed-single.html
    - shard-glk:          [DMESG-WARN][63] ([i915#5566] / [i915#716]) -> [PASS][64]
   [63]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk8/igt@gen9_exec_parse@allowed-single.html
   [64]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk5/igt@gen9_exec_parse@allowed-single.html

  * igt@i915_pm_dc@dc9-dpms:
    - {shard-rkl}:        [SKIP][65] ([i915#3361]) -> [PASS][66]
   [65]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-5/igt@i915_pm_dc@dc9-dpms.html
   [66]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@i915_pm_dc@dc9-dpms.html

  * igt@i915_pm_rc6_residency@rc6-idle@rcs0:
    - {shard-dg1}:        [FAIL][67] ([i915#3591]) -> [PASS][68]
   [67]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-dg1-16/igt@i915_pm_rc6_residency@rc6-idle@rcs0.html
   [68]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-dg1-15/igt@i915_pm_rc6_residency@rc6-idle@rcs0.html

  * igt@i915_pm_rpm@dpms-lpsp:
    - {shard-rkl}:        [SKIP][69] ([i915#1397]) -> [PASS][70]
   [69]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-3/igt@i915_pm_rpm@dpms-lpsp.html
   [70]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@i915_pm_rpm@dpms-lpsp.html

  * igt@i915_pm_rpm@pm-tiling:
    - {shard-rkl}:        [SKIP][71] ([fdo#109308]) -> [PASS][72] +1 similar issue
   [71]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-2/igt@i915_pm_rpm@pm-tiling.html
   [72]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@i915_pm_rpm@pm-tiling.html

  * igt@kms_cursor_legacy@flip-vs-cursor@atomic-transitions-varying-size:
    - shard-glk:          [FAIL][73] ([i915#2346]) -> [PASS][74] +1 similar issue
   [73]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk2/igt@kms_cursor_legacy@flip-vs-cursor@atomic-transitions-varying-size.html
   [74]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk1/igt@kms_cursor_legacy@flip-vs-cursor@atomic-transitions-varying-size.html

  * igt@kms_flip@2x-flip-vs-expired-vblank@ac-hdmi-a1-hdmi-a2:
    - shard-glk:          [FAIL][75] ([i915#79]) -> [PASS][76]
   [75]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-glk8/igt@kms_flip@2x-flip-vs-expired-vblank@ac-hdmi-a1-hdmi-a2.html
   [76]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-glk8/igt@kms_flip@2x-flip-vs-expired-vblank@ac-hdmi-a1-hdmi-a2.html

  * igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite:
    - {shard-rkl}:        [SKIP][77] ([i915#1849] / [i915#4098]) -> [PASS][78] +16 similar issues
   [77]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-4/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite.html
   [78]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite.html

  * igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-shrfb-draw-mmap-gtt:
    - {shard-tglu}:       [SKIP][79] ([i915#1849]) -> [PASS][80]
   [79]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-6/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-shrfb-draw-mmap-gtt.html
   [80]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-1/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-shrfb-draw-mmap-gtt.html

  * igt@kms_hdmi_inject@inject-audio:
    - {shard-tglu}:       [SKIP][81] ([i915#433]) -> [PASS][82]
   [81]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-3/igt@kms_hdmi_inject@inject-audio.html
   [82]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-4/igt@kms_hdmi_inject@inject-audio.html

  * igt@kms_properties@plane-properties-legacy:
    - {shard-rkl}:        [SKIP][83] ([i915#1849]) -> [PASS][84]
   [83]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-2/igt@kms_properties@plane-properties-legacy.html
   [84]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@kms_properties@plane-properties-legacy.html

  * igt@kms_psr@primary_render:
    - {shard-rkl}:        [SKIP][85] ([i915#1072]) -> [PASS][86] +2 similar issues
   [85]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-2/igt@kms_psr@primary_render.html
   [86]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@kms_psr@primary_render.html

  * igt@kms_universal_plane@universal-plane-pageflip-windowed-pipe-b:
    - {shard-tglu}:       [SKIP][87] ([fdo#109274]) -> [PASS][88]
   [87]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-6/igt@kms_universal_plane@universal-plane-pageflip-windowed-pipe-b.html
   [88]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-3/igt@kms_universal_plane@universal-plane-pageflip-windowed-pipe-b.html

  * igt@kms_vblank@pipe-b-query-forked:
    - {shard-rkl}:        [SKIP][89] ([i915#1845] / [i915#4098]) -> [PASS][90] +19 similar issues
   [89]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-rkl-4/igt@kms_vblank@pipe-b-query-forked.html
   [90]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-rkl-6/igt@kms_vblank@pipe-b-query-forked.html

  * igt@kms_vblank@pipe-c-ts-continuation-suspend:
    - {shard-tglu}:       [SKIP][91] ([i915#1845] / [i915#7651]) -> [PASS][92]
   [91]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-tglu-6/igt@kms_vblank@pipe-c-ts-continuation-suspend.html
   [92]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-tglu-3/igt@kms_vblank@pipe-c-ts-continuation-suspend.html

  * igt@perf_pmu@all-busy-idle-check-all:
    - {shard-dg1}:        [FAIL][93] -> [PASS][94]
   [93]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-dg1-17/igt@perf_pmu@all-busy-idle-check-all.html
   [94]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-dg1-15/igt@perf_pmu@all-busy-idle-check-all.html

  
#### Warnings ####

  * igt@runner@aborted:
    - shard-apl:          ([FAIL][95], [FAIL][96]) ([fdo#109271] / [i915#3002] / [i915#4312]) -> ([FAIL][97], [FAIL][98]) ([i915#3002] / [i915#4312])
   [95]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl8/igt@runner@aborted.html
   [96]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_12516/shard-apl7/igt@runner@aborted.html
   [97]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@runner@aborted.html
   [98]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/shard-apl8/igt@runner@aborted.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [fdo#109271]: https://bugs.freedesktop.org/show_bug.cgi?id=109271
  [fdo#109274]: https://bugs.freedesktop.org/show_bug.cgi?id=109274
  [fdo#109280]: https://bugs.freedesktop.org/show_bug.cgi?id=109280
  [fdo#109285]: https://bugs.freedesktop.org/show_bug.cgi?id=109285
  [fdo#109289]: https://bugs.freedesktop.org/show_bug.cgi?id=109289
  [fdo#109291]: https://bugs.freedesktop.org/show_bug.cgi?id=109291
  [fdo#109295]: https://bugs.freedesktop.org/show_bug.cgi?id=109295
  [fdo#109302]: https://bugs.freedesktop.org/show_bug.cgi?id=109302
  [fdo#109307]: https://bugs.freedesktop.org/show_bug.cgi?id=109307
  [fdo#109308]: https://bugs.freedesktop.org/show_bug.cgi?id=109308
  [fdo#109309]: https://bugs.freedesktop.org/show_bug.cgi?id=109309
  [fdo#109312]: https://bugs.freedesktop.org/show_bug.cgi?id=109312
  [fdo#109313]: https://bugs.freedesktop.org/show_bug.cgi?id=109313
  [fdo#109314]: https://bugs.freedesktop.org/show_bug.cgi?id=109314
  [fdo#109315]: https://bugs.freedesktop.org/show_bug.cgi?id=109315
  [fdo#109506]: https://bugs.freedesktop.org/show_bug.cgi?id=109506
  [fdo#109642]: https://bugs.freedesktop.org/show_bug.cgi?id=109642
  [fdo#110189]: https://bugs.freedesktop.org/show_bug.cgi?id=110189
  [fdo#110542]: https://bugs.freedesktop.org/show_bug.cgi?id=110542
  [fdo#110723]: https://bugs.freedesktop.org/show_bug.cgi?id=110723
  [fdo#111068]: https://bugs.freedesktop.org/show_bug.cgi?id=111068
  [fdo#111614]: https://bugs.freedesktop.org/show_bug.cgi?id=111614
  [fdo#111615]: https://bugs.freedesktop.org/show_bug.cgi?id=111615
  [fdo#111644]: https://bugs.freedesktop.org/show_bug.cgi?id=111644
  [fdo#111656]: https://bugs.freedesktop.org/show_bug.cgi?id=111656
  [fdo#111825]: https://bugs.freedesktop.org/show_bug.cgi?id=111825
  [fdo#111827]: https://bugs.freedesktop.org/show_bug.cgi?id=111827
  [fdo#112054]: https://bugs.freedesktop.org/show_bug.cgi?id=112054
  [fdo#112283]: https://bugs.freedesktop.org/show_bug.cgi?id=112283
  [i915#1072]: https://gitlab.freedesktop.org/drm/intel/issues/1072
  [i915#132]: https://gitlab.freedesktop.org/drm/intel/issues/132
  [i915#1397]: https://gitlab.freedesktop.org/drm/intel/issues/1397
  [i915#1722]: https://gitlab.freedesktop.org/drm/intel/issues/1722
  [i915#1755]: https://gitlab.freedesktop.org/drm/intel/issues/1755
  [i915#1825]: https://gitlab.freedesktop.org/drm/intel/issues/1825
  [i915#1839]: https://gitlab.freedesktop.org/drm/intel/issues/1839
  [i915#1845]: https://gitlab.freedesktop.org/drm/intel/issues/1845
  [i915#1849]: https://gitlab.freedesktop.org/drm/intel/issues/1849
  [i915#1902]: https://gitlab.freedesktop.org/drm/intel/issues/1902
  [i915#1937]: https://gitlab.freedesktop.org/drm/intel/issues/1937
  [i915#2190]: https://gitlab.freedesktop.org/drm/intel/issues/2190
  [i915#2346]: https://gitlab.freedesktop.org/drm/intel/issues/2346
  [i915#2437]: https://gitlab.freedesktop.org/drm/intel/issues/2437
  [i915#2527]: https://gitlab.freedesktop.org/drm/intel/issues/2527
  [i915#2575]: https://gitlab.freedesktop.org/drm/intel/issues/2575
  [i915#2582]: https://gitlab.freedesktop.org/drm/intel/issues/2582
  [i915#2587]: https://gitlab.freedesktop.org/drm/intel/issues/2587
  [i915#2658]: https://gitlab.freedesktop.org/drm/intel/issues/2658
  [i915#2672]: https://gitlab.freedesktop.org/drm/intel/issues/2672
  [i915#2705]: https://gitlab.freedesktop.org/drm/intel/issues/2705
  [i915#280]: https://gitlab.freedesktop.org/drm/intel/issues/280
  [i915#284]: https://gitlab.freedesktop.org/drm/intel/issues/284
  [i915#2842]: https://gitlab.freedesktop.org/drm/intel/issues/2842
  [i915#2856]: https://gitlab.freedesktop.org/drm/intel/issues/2856
  [i915#2898]: https://gitlab.freedesktop.org/drm/intel/issues/2898
  [i915#2920]: https://gitlab.freedesktop.org/drm/intel/issues/2920
  [i915#2994]: https://gitlab.freedesktop.org/drm/intel/issues/2994
  [i915#3002]: https://gitlab.freedesktop.org/drm/intel/issues/3002
  [i915#3116]: https://gitlab.freedesktop.org/drm/intel/issues/3116
  [i915#3281]: https://gitlab.freedesktop.org/drm/intel/issues/3281
  [i915#3282]: https://gitlab.freedesktop.org/drm/intel/issues/3282
  [i915#3291]: https://gitlab.freedesktop.org/drm/intel/issues/3291
  [i915#3297]: https://gitlab.freedesktop.org/drm/intel/issues/3297
  [i915#3299]: https://gitlab.freedesktop.org/drm/intel/issues/3299
  [i915#3318]: https://gitlab.freedesktop.org/drm/intel/issues/3318
  [i915#3323]: https://gitlab.freedesktop.org/drm/intel/issues/3323
  [i915#3359]: https://gitlab.freedesktop.org/drm/intel/issues/3359
  [i915#3361]: https://gitlab.freedesktop.org/drm/intel/issues/3361
  [i915#3458]: https://gitlab.freedesktop.org/drm/intel/issues/3458
  [i915#3469]: https://gitlab.freedesktop.org/drm/intel/issues/3469
  [i915#3528]: https://gitlab.freedesktop.org/drm/intel/issues/3528
  [i915#3539]: https://gitlab.freedesktop.org/drm/intel/issues/3539
  [i915#3546]: https://gitlab.freedesktop.org/drm/intel/issues/3546
  [i915#3555]: https://gitlab.freedesktop.org/drm/intel/issues/3555
  [i915#3558]: https://gitlab.freedesktop.org/drm/intel/issues/3558
  [i915#3591]: https://gitlab.freedesktop.org/drm/intel/issues/3591
  [i915#3637]: https://gitlab.freedesktop.org/drm/intel/issues/3637
  [i915#3638]: https://gitlab.freedesktop.org/drm/intel/issues/3638
  [i915#3639]: https://gitlab.freedesktop.org/drm/intel/issues/3639
  [i915#3689]: https://gitlab.freedesktop.org/drm/intel/issues/3689
  [i915#3708]: https://gitlab.freedesktop.org/drm/intel/issues/3708
  [i915#3734]: https://gitlab.freedesktop.org/drm/intel/issues/3734
  [i915#3742]: https://gitlab.freedesktop.org/drm/intel/issues/3742
  [i915#3826]: https://gitlab.freedesktop.org/drm/intel/issues/3826
  [i915#3840]: https://gitlab.freedesktop.org/drm/intel/issues/3840
  [i915#3886]: https://gitlab.freedesktop.org/drm/intel/issues/3886
  [i915#3955]: https://gitlab.freedesktop.org/drm/intel/issues/3955
  [i915#4070]: https://gitlab.freedesktop.org/drm/intel/issues/4070
  [i915#4078]: https://gitlab.freedesktop.org/drm/intel/issues/4078
  [i915#4083]: https://gitlab.freedesktop.org/drm/intel/issues/4083
  [i915#4098]: https://gitlab.freedesktop.org/drm/intel/issues/4098
  [i915#4103]: https://gitlab.freedesktop.org/drm/intel/issues/4103
  [i915#4212]: https://gitlab.freedesktop.org/drm/intel/issues/4212
  [i915#426]: https://gitlab.freedesktop.org/drm/intel/issues/426
  [i915#4270]: https://gitlab.freedesktop.org/drm/intel/issues/4270
  [i915#4312]: https://gitlab.freedesktop.org/drm/intel/issues/4312
  [i915#433]: https://gitlab.freedesktop.org/drm/intel/issues/433
  [i915#4349]: https://gitlab.freedesktop.org/drm/intel/issues/4349
  [i915#4387]: https://gitlab.freedesktop.org/drm/intel/issues/4387
  [i915#4525]: https://gitlab.freedesktop.org/drm/intel/issues/4525
  [i915#4538]: https://gitlab.freedesktop.org/drm/intel/issues/4538
  [i915#4613]: https://gitlab.freedesktop.org/drm/intel/issues/4613
  [i915#4771]: https://gitlab.freedesktop.org/drm/intel/issues/4771
  [i915#4812]: https://gitlab.freedesktop.org/drm/intel/issues/4812
  [i915#4833]: https://gitlab.freedesktop.org/drm/intel/issues/4833
  [i915#4884]: https://gitlab.freedesktop.org/drm/intel/issues/4884
  [i915#4991]: https://gitlab.freedesktop.org/drm/intel/issues/4991
  [i915#5122]: https://gitlab.freedesktop.org/drm/intel/issues/5122
  [i915#5176]: https://gitlab.freedesktop.org/drm/intel/issues/5176
  [i915#5235]: https://gitlab.freedesktop.org/drm/intel/issues/5235
  [i915#5286]: https://gitlab.freedesktop.org/drm/intel/issues/5286
  [i915#5288]: https://gitlab.freedesktop.org/drm/intel/issues/5288
  [i915#5289]: https://gitlab.freedesktop.org/drm/intel/issues/5289
  [i915#5325]: https://gitlab.freedesktop.org/drm/intel/issues/5325
  [i915#5327]: https://gitlab.freedesktop.org/drm/intel/issues/5327
  [i915#533]: https://gitlab.freedesktop.org/drm/intel/issues/533
  [i915#5334]: https://gitlab.freedesktop.org/drm/intel/issues/5334
  [i915#5439]: https://gitlab.freedesktop.org/drm/intel/issues/5439
  [i915#5461]: https://gitlab.freedesktop.org/drm/intel/issues/5461
  [i915#5563]: https://gitlab.freedesktop.org/drm/intel/issues/5563
  [i915#5566]: https://gitlab.freedesktop.org/drm/intel/issues/5566
  [i915#5784]: https://gitlab.freedesktop.org/drm/intel/issues/5784
  [i915#6095]: https://gitlab.freedesktop.org/drm/intel/issues/6095
  [i915#6227]: https://gitlab.freedesktop.org/drm/intel/issues/6227
  [i915#6247]: https://gitlab.freedesktop.org/drm/intel/issues/6247
  [i915#6268]: https://gitlab.freedesktop.org/drm/intel/issues/6268
  [i915#6335]: https://gitlab.freedesktop.org/drm/intel/issues/6335
  [i915#6433]: https://gitlab.freedesktop.org/drm/intel/issues/6433
  [i915#6497]: https://gitlab.freedesktop.org/drm/intel/issues/6497
  [i915#6524]: https://gitlab.freedesktop.org/drm/intel/issues/6524
  [i915#658]: https://gitlab.freedesktop.org/drm/intel/issues/658
  [i915#6590]: https://gitlab.freedesktop.org/drm/intel/issues/6590
  [i915#6768]: https://gitlab.freedesktop.org/drm/intel/issues/6768
  [i915#7116]: https://gitlab.freedesktop.org/drm/intel/issues/7116
  [i915#7118]: https://gitlab.freedesktop.org/drm/intel/issues/7118
  [i915#7128]: https://gitlab.freedesktop.org/drm/intel/issues/7128
  [i915#716]: https://gitlab.freedesktop.org/drm/intel/issues/716
  [i915#7205]: https://gitlab.freedesktop.org/drm/intel/issues/7205
  [i915#7443]: https://gitlab.freedesktop.org/drm/intel/issues/7443
  [i915#7456]: https://gitlab.freedesktop.org/drm/intel/issues/7456
  [i915#7561]: https://gitlab.freedesktop.org/drm/intel/issues/7561
  [i915#7651]: https://gitlab.freedesktop.org/drm/intel/issues/7651
  [i915#7697]: https://gitlab.freedesktop.org/drm/intel/issues/7697
  [i915#7701]: https://gitlab.freedesktop.org/drm/intel/issues/7701
  [i915#7708]: https://gitlab.freedesktop.org/drm/intel/issues/7708
  [i915#7711]: https://gitlab.freedesktop.org/drm/intel/issues/7711
  [i915#79]: https://gitlab.freedesktop.org/drm/intel/issues/79


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_7100 -> IGTPW_8248
  * Piglit: piglit_4509 -> None

  CI-20190529: 20190529
  CI_DRM_12516: fc2ae74d6521d5237f8ad1ae6bf985a6eb3f1ea2 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_8248: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html
  IGT_7100: 04466b02a9b5356d266a899daa5183c1f6b0e20f @ https://gitlab.freedesktop.org/drm/igt-gpu-tools.git
  piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_8248/index.html

[-- Attachment #2: Type: text/html, Size: 27747 bytes --]

^ permalink raw reply	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-20 11:55 ` Melissa Wen
@ 2022-12-20 18:20   ` Alex Hung
  2022-12-20 19:06     ` Melissa Wen
  0 siblings, 1 reply; 8+ messages in thread
From: Alex Hung @ 2022-12-20 18:20 UTC (permalink / raw)
  To: Melissa Wen; +Cc: igt-dev, markyacoub



On 2022-12-20 04:55, Melissa Wen wrote:
> On 12/19, Alex Hung wrote:
>> 64d0ff72 introduced a workaround for ctm-max but the condition caused
>> other ctm tests to skip unintentionally on some platforms.
> 
> Hi Alex,
> 
> Can't we just drop this gamma/degamma setup for CTM tests?
> 
> I remember thinking about removing this setup before... From DRM docs,
> "Each of the properties are optional." so I don't see an explicity
> reason for degamma/gamma dependencies. I think we should only test the
> CTM property here, or change the name of the subtest to describe a full
> color mgmt testing.
> 
> I took a look at previous discussions on having or not degamma/gamma
> here and if it's an intel limitation, than I prefer to explicitly
> restrict it for i915 HW. What do you think?

Hi Melissa,

I may not understand you 100%.

Could you please share what you'd like to change, or create a patch for 
more discussion?

Cheers,
Alex

> 
> Best regards,
> 
> Melissa
> 
>>
>> The patch improves the condition by keeping the original condition
>> for i915 and checking degamma and gamma props for others. The
>> following subtests will be executed instead of skipped.
>>
>>    kms_color@ctm-0-25@*
>>    kms_color@ctm-0-50@*
>>    kms_color@ctm-0-75@*
>>    kms_color@ctm-red-to-blue@*
>>    kms_color@ctm-negative@*
>>
>> Signed-off-by: Alex Hung <alex.hung@amd.com>
>> ---
>>   tests/kms_color.c | 30 +++++++++++++++++++++---------
>>   1 file changed, 21 insertions(+), 9 deletions(-)
>>
>> diff --git a/tests/kms_color.c b/tests/kms_color.c
>> index d016cefb..450bf7ca 100644
>> --- a/tests/kms_color.c
>> +++ b/tests/kms_color.c
>> @@ -446,6 +446,26 @@ end:
>>   	return ret;
>>   }
>>   
>> +static bool is_gamma_degamma_supported(data_t *data,
>> +				       igt_plane_t *primary,
>> +				       color_t *before,
>> +				       color_t *after)
>> +{
>> +	/*
>> +	 * Don't program LUT's for max CTM cases, as limitation of
>> +	 * representing intermediate values between 0 and 1.0 causes
>> +	 * rounding issues and inaccuracies leading to crc mismatch.
>> +	 */
>> +	if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t)))
>> +		return true;
>> +
>> +	if (igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT) &&
>> +	    igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT))
>> +		return true;
>> +
>> +	return false;
>> +}
>> +
>>   /*
>>    * Draw 3 rectangles using before colors with the ctm matrix apply and verify
>>    * the CRC is equal to using after colors with an identify ctm matrix.
>> @@ -493,14 +513,7 @@ static bool test_pipe_ctm(data_t *data,
>>   	igt_assert(fb_modeset_id);
>>   	igt_plane_set_fb(primary, &fb_modeset);
>>   
>> -	/*
>> -	 * Don't program LUT's for max CTM cases, as limitation of
>> -	 * representing intermediate values between 0 and 1.0 causes
>> -	 * rounding issues and inaccuracies leading to crc mismatch.
>> -	 */
>> -	if (memcmp(before, after, sizeof(color_t))) {
>> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
>> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
>> +	if (is_gamma_degamma_supported(data, primary, before, after)) {
>>   
>>   		degamma_linear = generate_table(data->degamma_lut_size, 1.0);
>>   		gamma_linear = generate_table(data->gamma_lut_size, 1.0);
>> @@ -508,7 +521,6 @@ static bool test_pipe_ctm(data_t *data,
>>   		set_degamma(data, primary->pipe, degamma_linear);
>>   		set_gamma(data, primary->pipe, gamma_linear);
>>   	} else {
>> -		/* Disable Degamma and Gamma for ctm max test */
>>   		disable_degamma(primary->pipe);
>>   		disable_gamma(primary->pipe);
>>   	}
>> -- 
>> 2.25.1
>>

^ permalink raw reply	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-20 18:20   ` Alex Hung
@ 2022-12-20 19:06     ` Melissa Wen
  2022-12-20 23:49       ` Alex Hung
  0 siblings, 1 reply; 8+ messages in thread
From: Melissa Wen @ 2022-12-20 19:06 UTC (permalink / raw)
  To: Alex Hung; +Cc: igt-dev, markyacoub

[-- Attachment #1: Type: text/plain, Size: 5810 bytes --]

On 12/20, Alex Hung wrote:
> 
> 
> On 2022-12-20 04:55, Melissa Wen wrote:
> > On 12/19, Alex Hung wrote:
> > > 64d0ff72 introduced a workaround for ctm-max but the condition caused
> > > other ctm tests to skip unintentionally on some platforms.
> > 
> > Hi Alex,
> > 
> > Can't we just drop this gamma/degamma setup for CTM tests?
> > 
> > I remember thinking about removing this setup before... From DRM docs,
> > "Each of the properties are optional." so I don't see an explicity
> > reason for degamma/gamma dependencies. I think we should only test the
> > CTM property here, or change the name of the subtest to describe a full
> > color mgmt testing.
> > 
> > I took a look at previous discussions on having or not degamma/gamma
> > here and if it's an intel limitation, than I prefer to explicitly
> > restrict it for i915 HW. What do you think?
> 
> Hi Melissa,
> 
> I may not understand you 100%.
> 
> Could you please share what you'd like to change, or create a patch for more
> discussion?

My suggestion is basically disable degamma and gamma and only set them for
i915 + not max ctm case, something like the following diff:

diff --git a/tests/kms_color.c b/tests/kms_color.c
index d016cefb..2be4095d 100644
--- a/tests/kms_color.c
+++ b/tests/kms_color.c
@@ -493,12 +493,16 @@ static bool test_pipe_ctm(data_t *data,
        igt_assert(fb_modeset_id);
        igt_plane_set_fb(primary, &fb_modeset);

+       disable_degamma(primary->pipe);
+       disable_gamma(primary->pipe);
+
        /*
         * Don't program LUT's for max CTM cases, as limitation of
         * representing intermediate values between 0 and 1.0 causes
         * rounding issues and inaccuracies leading to crc mismatch.
         */
-       if (memcmp(before, after, sizeof(color_t))) {
+       if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t))) {
                igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
                igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));

@@ -507,10 +511,6 @@ static bool test_pipe_ctm(data_t *data,

                set_degamma(data, primary->pipe, degamma_linear);
                set_gamma(data, primary->pipe, gamma_linear);
-       } else {
-               /* Disable Degamma and Gamma for ctm max test */
-               disable_degamma(primary->pipe);
-               disable_gamma(primary->pipe);
        }

        disable_ctm(primary->pipe);

> 
> Cheers,
> Alex
> 
> > 
> > Best regards,
> > 
> > Melissa
> > 
> > > 
> > > The patch improves the condition by keeping the original condition
> > > for i915 and checking degamma and gamma props for others. The
> > > following subtests will be executed instead of skipped.
> > > 
> > >    kms_color@ctm-0-25@*
> > >    kms_color@ctm-0-50@*
> > >    kms_color@ctm-0-75@*
> > >    kms_color@ctm-red-to-blue@*
> > >    kms_color@ctm-negative@*
> > > 
> > > Signed-off-by: Alex Hung <alex.hung@amd.com>
> > > ---
> > >   tests/kms_color.c | 30 +++++++++++++++++++++---------
> > >   1 file changed, 21 insertions(+), 9 deletions(-)
> > > 
> > > diff --git a/tests/kms_color.c b/tests/kms_color.c
> > > index d016cefb..450bf7ca 100644
> > > --- a/tests/kms_color.c
> > > +++ b/tests/kms_color.c
> > > @@ -446,6 +446,26 @@ end:
> > >   	return ret;
> > >   }
> > > +static bool is_gamma_degamma_supported(data_t *data,
> > > +				       igt_plane_t *primary,
> > > +				       color_t *before,
> > > +				       color_t *after)
> > > +{
> > > +	/*
> > > +	 * Don't program LUT's for max CTM cases, as limitation of
> > > +	 * representing intermediate values between 0 and 1.0 causes
> > > +	 * rounding issues and inaccuracies leading to crc mismatch.
> > > +	 */
> > > +	if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t)))
> > > +		return true;
> > > +
> > > +	if (igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT) &&
> > > +	    igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT))
> > > +		return true;
> > > +
> > > +	return false;
> > > +}
> > > +
> > >   /*
> > >    * Draw 3 rectangles using before colors with the ctm matrix apply and verify
> > >    * the CRC is equal to using after colors with an identify ctm matrix.
> > > @@ -493,14 +513,7 @@ static bool test_pipe_ctm(data_t *data,
> > >   	igt_assert(fb_modeset_id);
> > >   	igt_plane_set_fb(primary, &fb_modeset);
> > > -	/*
> > > -	 * Don't program LUT's for max CTM cases, as limitation of
> > > -	 * representing intermediate values between 0 and 1.0 causes
> > > -	 * rounding issues and inaccuracies leading to crc mismatch.
> > > -	 */
> > > -	if (memcmp(before, after, sizeof(color_t))) {
> > > -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
> > > -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
> > > +	if (is_gamma_degamma_supported(data, primary, before, after)) {
> > >   		degamma_linear = generate_table(data->degamma_lut_size, 1.0);
> > >   		gamma_linear = generate_table(data->gamma_lut_size, 1.0);
> > > @@ -508,7 +521,6 @@ static bool test_pipe_ctm(data_t *data,
> > >   		set_degamma(data, primary->pipe, degamma_linear);
> > >   		set_gamma(data, primary->pipe, gamma_linear);
> > >   	} else {
> > > -		/* Disable Degamma and Gamma for ctm max test */
> > >   		disable_degamma(primary->pipe);
> > >   		disable_gamma(primary->pipe);
> > >   	}
> > > -- 
> > > 2.25.1
> > > 

[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 833 bytes --]

^ permalink raw reply related	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests
  2022-12-20 19:06     ` Melissa Wen
@ 2022-12-20 23:49       ` Alex Hung
  0 siblings, 0 replies; 8+ messages in thread
From: Alex Hung @ 2022-12-20 23:49 UTC (permalink / raw)
  To: Melissa Wen; +Cc: igt-dev, markyacoub



On 2022-12-20 12:06, Melissa Wen wrote:
> On 12/20, Alex Hung wrote:
>>
>>
>> On 2022-12-20 04:55, Melissa Wen wrote:
>>> On 12/19, Alex Hung wrote:
>>>> 64d0ff72 introduced a workaround for ctm-max but the condition caused
>>>> other ctm tests to skip unintentionally on some platforms.
>>>
>>> Hi Alex,
>>>
>>> Can't we just drop this gamma/degamma setup for CTM tests?
>>>
>>> I remember thinking about removing this setup before... From DRM docs,
>>> "Each of the properties are optional." so I don't see an explicity
>>> reason for degamma/gamma dependencies. I think we should only test the
>>> CTM property here, or change the name of the subtest to describe a full
>>> color mgmt testing.
>>>
>>> I took a look at previous discussions on having or not degamma/gamma
>>> here and if it's an intel limitation, than I prefer to explicitly
>>> restrict it for i915 HW. What do you think?
>>
>> Hi Melissa,
>>
>> I may not understand you 100%.
>>
>> Could you please share what you'd like to change, or create a patch for more
>> discussion?
> 
> My suggestion is basically disable degamma and gamma and only set them for
> i915 + not max ctm case, something like the following diff:
> 
> diff --git a/tests/kms_color.c b/tests/kms_color.c
> index d016cefb..2be4095d 100644
> --- a/tests/kms_color.c
> +++ b/tests/kms_color.c
> @@ -493,12 +493,16 @@ static bool test_pipe_ctm(data_t *data,
>          igt_assert(fb_modeset_id);
>          igt_plane_set_fb(primary, &fb_modeset);
> 
> +       disable_degamma(primary->pipe);
> +       disable_gamma(primary->pipe);
> +
>          /*
> -        * Don't program LUT's for max CTM cases, as limitation of
> -        * representing intermediate values between 0 and 1.0 causes
> -        * rounding issues and inaccuracies leading to crc mismatch.
> +        * Program LUT's only for i915, but not in max CTM cases, as limitation
> +        * of representing intermediate values between 0 and 1.0 causes
> +        * rounding issues and inaccuracies leading to crc mismatch in i915
> +        * devices.
>           */
> -       if (memcmp(before, after, sizeof(color_t))) {
> +       if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t))) {
>                  igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
>                  igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
> 
> @@ -507,10 +511,6 @@ static bool test_pipe_ctm(data_t *data,
> 
>                  set_degamma(data, primary->pipe, degamma_linear);
>                  set_gamma(data, primary->pipe, gamma_linear);
> -       } else {
> -               /* Disable Degamma and Gamma for ctm max test */
> -               disable_degamma(primary->pipe);
> -               disable_gamma(primary->pipe);
>          }
> 
>          disable_ctm(primary->pipe);
> 

This looks good to me, and I also tested it on 2A + 1I systems and it 
ran fine.



>>
>> Cheers,
>> Alex
>>
>>>
>>> Best regards,
>>>
>>> Melissa
>>>
>>>>
>>>> The patch improves the condition by keeping the original condition
>>>> for i915 and checking degamma and gamma props for others. The
>>>> following subtests will be executed instead of skipped.
>>>>
>>>>     kms_color@ctm-0-25@*
>>>>     kms_color@ctm-0-50@*
>>>>     kms_color@ctm-0-75@*
>>>>     kms_color@ctm-red-to-blue@*
>>>>     kms_color@ctm-negative@*
>>>>
>>>> Signed-off-by: Alex Hung <alex.hung@amd.com>
>>>> ---
>>>>    tests/kms_color.c | 30 +++++++++++++++++++++---------
>>>>    1 file changed, 21 insertions(+), 9 deletions(-)
>>>>
>>>> diff --git a/tests/kms_color.c b/tests/kms_color.c
>>>> index d016cefb..450bf7ca 100644
>>>> --- a/tests/kms_color.c
>>>> +++ b/tests/kms_color.c
>>>> @@ -446,6 +446,26 @@ end:
>>>>    	return ret;
>>>>    }
>>>> +static bool is_gamma_degamma_supported(data_t *data,
>>>> +				       igt_plane_t *primary,
>>>> +				       color_t *before,
>>>> +				       color_t *after)
>>>> +{
>>>> +	/*
>>>> +	 * Don't program LUT's for max CTM cases, as limitation of
>>>> +	 * representing intermediate values between 0 and 1.0 causes
>>>> +	 * rounding issues and inaccuracies leading to crc mismatch.
>>>> +	 */
>>>> +	if (is_i915_device(data->drm_fd) && memcmp(before, after, sizeof(color_t)))
>>>> +		return true;
>>>> +
>>>> +	if (igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT) &&
>>>> +	    igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT))
>>>> +		return true;
>>>> +
>>>> +	return false;
>>>> +}
>>>> +
>>>>    /*
>>>>     * Draw 3 rectangles using before colors with the ctm matrix apply and verify
>>>>     * the CRC is equal to using after colors with an identify ctm matrix.
>>>> @@ -493,14 +513,7 @@ static bool test_pipe_ctm(data_t *data,
>>>>    	igt_assert(fb_modeset_id);
>>>>    	igt_plane_set_fb(primary, &fb_modeset);
>>>> -	/*
>>>> -	 * Don't program LUT's for max CTM cases, as limitation of
>>>> -	 * representing intermediate values between 0 and 1.0 causes
>>>> -	 * rounding issues and inaccuracies leading to crc mismatch.
>>>> -	 */
>>>> -	if (memcmp(before, after, sizeof(color_t))) {
>>>> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_DEGAMMA_LUT));
>>>> -		igt_require(igt_pipe_obj_has_prop(primary->pipe, IGT_CRTC_GAMMA_LUT));
>>>> +	if (is_gamma_degamma_supported(data, primary, before, after)) {
>>>>    		degamma_linear = generate_table(data->degamma_lut_size, 1.0);
>>>>    		gamma_linear = generate_table(data->gamma_lut_size, 1.0);
>>>> @@ -508,7 +521,6 @@ static bool test_pipe_ctm(data_t *data,
>>>>    		set_degamma(data, primary->pipe, degamma_linear);
>>>>    		set_gamma(data, primary->pipe, gamma_linear);
>>>>    	} else {
>>>> -		/* Disable Degamma and Gamma for ctm max test */
>>>>    		disable_degamma(primary->pipe);
>>>>    		disable_gamma(primary->pipe);
>>>>    	}
>>>> -- 
>>>> 2.25.1
>>>>

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] ✗ Fi.CI.BUILD: failure for tests/kms_color: Reduce skips on some ctm-* tests (rev2)
  2022-12-19 19:21 [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests Alex Hung
                   ` (2 preceding siblings ...)
  2022-12-20 18:14 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
@ 2022-12-21 11:08 ` Patchwork
  3 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2022-12-21 11:08 UTC (permalink / raw)
  To: Melissa Wen; +Cc: igt-dev

== Series Details ==

Series: tests/kms_color: Reduce skips on some ctm-* tests (rev2)
URL   : https://patchwork.freedesktop.org/series/112075/
State : failure

== Summary ==

Applying: tests/kms_color: Reduce skips on some ctm-* tests
Using index info to reconstruct a base tree...
Patch failed at 0001 tests/kms_color: Reduce skips on some ctm-* tests
When you have resolved this problem, run "git am --continue".
If you prefer to skip this patch, run "git am --skip" instead.
To restore the original branch and stop patching, run "git am --abort".


^ permalink raw reply	[flat|nested] 8+ messages in thread

end of thread, other threads:[~2022-12-21 11:08 UTC | newest]

Thread overview: 8+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -493,12 +493,16 @@ static bool test_pipe_ctm(data_t *data,
        /*
-        * Don't program LUT's for max CTM cases, as limitation of
-        * representing intermediate values between 0 and 1.0 causes
-        * rounding issues and inaccuracies leading to crc mismatch.
+        * Program LUT's only for i915, but not in max CTM cases, as limitation
+        * of representing intermediate values between 0 and 1.0 causes
+        * rounding issues and inaccuracies leading to crc mismatch in i915
+        * devices.
         */
2022-12-19 19:21 [igt-dev] [PATCH] tests/kms_color: Reduce skips on some ctm-* tests Alex Hung
2022-12-20 11:55 ` Melissa Wen
2022-12-20 18:20   ` Alex Hung
2022-12-20 19:06     ` Melissa Wen
2022-12-20 23:49       ` Alex Hung
2022-12-20 15:22 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
2022-12-20 18:14 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
2022-12-21 11:08 ` [igt-dev] ✗ Fi.CI.BUILD: failure for tests/kms_color: Reduce skips on some ctm-* tests (rev2) Patchwork

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox